For simple use cases, generate ternary plots using the point-and-click Shiny app:
Maintainer: Martin R. Smith [email protected] (ORCID) [copyright holder]
Other contributors:
Lilian Sanselme [contributor]
install.packages('Ternary')
Ternary::TernaryApp()
For greater control over your plots, use the R command line;
for usage instructions, consult the guidance article
online or by
typing vignette('Ternary', 'Ternary') at the R console.
Useful links: