powered by
Convert cartesian (x, y) coordinates to a point in ternary space.
XYToTernary(x, y, direction = getOption("ternDirection", 1L))XYToHoldridge(x, y)XYToPetPrec(x, y)
XYToHoldridge(x, y)
XYToPetPrec(x, y)
XYToTernary() Returns the ternary point(s) corresponding to the specified x and y coordinates, where a + b + c = 1.
XYToTernary()
Numeric values giving the x and y coordinates of a point or points.
(optional) Integer specifying the direction that the current ternary plot should point: 1, up; 2, right; 3, down; 4, left.
Martin R. Smith (martin.smith@durham.ac.uk)
Other coordinate translation functions: ReflectedEquivalents(), TernaryCoords(), TriangleCentres()
ReflectedEquivalents()
TernaryCoords()
TriangleCentres()
XYToTernary(c(0.1, 0.2), 0.5)
Run the code above in your browser using DataLab